@@ -5,6 +5,7 @@
 import datetime
 import logging
 import os
+import shapely.geometry
 
 # External Imports
 import pandas as pd
@@ -30,7 +31,7 @@ def to_csv(data, product, product_subtype, location_type=None, output_dir=None):
         file_name = "_".join([date, product, product_subtype]) + ".csv"
 
     if not output_dir:
-        output_dir = os.getcwd() + "/data_csv"
+        output_dir = os.getcwd() + "/output_data"
 
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
@@ -44,6 +45,9 @@ def to_csv(data, product, product_subtype, location_type=None, output_dir=None):
         elif product_subtype == 'summary':
             df = format_adaptation_summary(data)
 
+        elif product_subtype == 'summary_detail':
+            df = format_adaptation_summary_detail(data)
+
         else:
             raise NotImplementedError
 
@@ -83,6 +87,13 @@ def to_csv(data, product, product_subtype, location_type=None, output_dir=None):
             else:
                 df = format_historic_summary(data)
 
+        elif product_subtype == 'summary_event':
+            if location_type == 'property':
+                df = format_historic_summary_event_property(data)
+
+            else:
+                df = format_historic_summary_event(data)
+
         else:
             raise NotImplementedError
 
@@ -136,11 +147,33 @@ def to_csv(data, product, product_subtype, location_type=None, output_dir=None):
         raise NotImplementedError
 
     # Export CSVs
-    df.fillna(pd.NA, inplace=True)
-    df.to_csv(output_dir + '/' + file_name, index=False)
+    if df['valid_id'].all():
+        df = df.drop(columns=['valid_id'])
+    else:
+        df['valid_id'] = df['valid_id'].fillna(True)
+
+    df.fillna(pd.NA).astype(str).to_csv(output_dir + '/' + file_name, index=False)
     logging.info("CSV generated to '{}'.".format(output_dir + '/' + file_name))
 
 
+def get_geom_center(geom):
+
+    if hasattr(geom, "center"):
+        if isinstance(geom.center, shapely.geometry.MultiPolygon):
+            return {"latitude": geom.center.centroid.y, "longitude": geom.center.centroid.x}
+
+        elif isinstance(geom.center, shapely.geometry.Point):
+            return {"latitude": geom.center.y, "longitude": geom.center.x}
+
+        else:
+            raise NotImplementedError
+
+    elif hasattr(geom, "y") and hasattr(geom, "x"):
+        return {"latitude": geom.y, "longitude": geom.x}
+
+    return {"latitude": None, "longitude": None}
+
+
 def format_adaptation_detail(data):
     """Reformat the list of data to Adaptation Detail format
 
@@ -150,14 +183,17 @@ def format_adaptation_detail(data):
         A pandas formatted DataFrame
     """
     df = pd.DataFrame([vars(o) for o in data]).explode('type').explode('scenario').reset_index(drop=True)
-    df.drop(["serving", "geometry"], axis=1, inplace=True)
     df['adaptationId'] = df['adaptationId'].astype('Int64').apply(str)
     df['returnPeriod'] = df['returnPeriod'].astype('Int64').apply(str)
-    return df[['adaptationId', 'name', 'type', 'scenario', 'conveyance', 'returnPeriod']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+
+    return df[['adaptationId', 'valid_id', 'name', 'type', 'scenario', 'conveyance', 'returnPeriod',
+               'latitude', 'longitude']]
 
 
 def format_adaptation_summary(data):
-    """Reformat the list of data to Adaptation Summary format
+    """Reformat the list of data to Adaptation Summary Detail format
 
     Args:
         data (list): A list of FSF object
@@ -166,7 +202,24 @@ def format_adaptation_summary(data):
     """
     df = pd.DataFrame([vars(o) for o in data]).explode('adaptation').reset_index(drop=True)
     df['fsid'] = df['fsid'].apply(str)
-    return df[['fsid', 'adaptation', 'properties']]
+    df['adaptation'] = df['adaptation'].astype('Int64').apply(str)
+    return df[['fsid', 'valid_id', 'adaptation', 'properties']]
+
+
+def format_adaptation_summary_detail(data):
+    """Reformat the list of data to Adaptation Summary format
+
+    Args:
+        data (list): A list of FSF object
+    Returns:
+        A pandas formatted DataFrame
+    """
+
+    summary = format_adaptation_summary(data[0])
+    detail = format_adaptation_detail(data[1])
+
+    return pd.merge(summary, detail, left_on=['adaptation', 'valid_id'], right_on=['adaptationId', 'valid_id'],
+                    how='left').drop('adaptationId', axis=1)
 
 
 def format_probability_chance(data):
@@ -183,12 +236,15 @@ def format_probability_chance(data):
         df = df.explode('data').reset_index(drop=True)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['year'] = df['year'].astype('Int64').apply(str)
         df['threshold'] = df['threshold'].astype('Int64').apply(str)
-        df['low'] = df['low'].round(3)
-        df['mid'] = df['mid'].round(3)
-        df['high'] = df['high'].round(3)
+        if df['low'] is None:
+            df['low'] = df['low'].round(3)
+        if df['mid'] is None:
+            df['mid'] = df['mid'].round(3)
+        if df['high'] is None:
+            df['high'] = df['high'].round(3)
     else:
         df['fsid'] = df['fsid'].apply(str)
         df.drop(['chance'], axis=1, inplace=True)
@@ -198,7 +254,7 @@ def format_probability_chance(data):
         df['mid'] = pd.NA
         df['high'] = pd.NA
 
-    return df[['fsid', 'year', 'threshold', 'low', 'mid', 'high']]
+    return df[['fsid', 'valid_id', 'year', 'threshold', 'low', 'mid', 'high']]
 
 
 def format_probability_count(data):
@@ -217,7 +273,7 @@ def format_probability_count(data):
         df = df.explode('data').reset_index(drop=True)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
         df = pd.concat([df.drop(['count'], axis=1), df['count'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['year'] = df['year'].astype('Int64').apply(str)
         df['returnPeriod'] = df['returnPeriod'].astype('Int64').apply(str)
         df['bin'] = df['bin'].astype('Int64').apply(str)
@@ -234,7 +290,7 @@ def format_probability_count(data):
         df['mid'] = pd.NA
         df['high'] = pd.NA
 
-    return df[['fsid', 'year', 'returnPeriod', 'bin', 'low', 'mid', 'high']]
+    return df[['fsid', 'valid_id', 'year', 'returnPeriod', 'bin', 'low', 'mid', 'high']]
 
 
 def format_probability_count_summary(data):
@@ -245,16 +301,14 @@ def format_probability_count_summary(data):
     Returns:
         A pandas formatted DataFrame
     """
-    # listed_data = [{'fsid': attr.fsid, 'location': [{'state': attr.state}, {'city': attr.city}, {'zcta': attr.zcta},
-    #                                                 {'neighborhood': attr.neighborhood}, {'tract': attr.tract},
-    #                                                 {'county': attr.county}, {'cd': attr.cd}]} for attr in data]
-    listed_data = [{'fsid': attr.fsid, 'location': [{'location': 'state', 'data': attr.state},
-                                                    {'location': 'city', 'data': attr.city},
-                                                    {'location': 'zcta', 'data': attr.zcta},
-                                                    {'location': 'neighborhood', 'data': attr.neighborhood},
-                                                    {'location': 'tract', 'data': attr.tract},
-                                                    {'location': 'county', 'data': attr.county},
-                                                    {'location': 'cd', 'data': attr.cd}]} for attr in data]
+    listed_data = [{'fsid': attr.fsid, 'valid_id': attr.valid_id,
+                    'location': [{'location': 'state', 'data': attr.state},
+                                 {'location': 'city', 'data': attr.city},
+                                 {'location': 'zcta', 'data': attr.zcta},
+                                 {'location': 'neighborhood', 'data': attr.neighborhood},
+                                 {'location': 'tract', 'data': attr.tract},
+                                 {'location': 'county', 'data': attr.county},
+                                 {'location': 'cd', 'data': attr.cd}]} for attr in data]
 
     df = pd.DataFrame(listed_data).explode('location').reset_index(drop=True)
     df.rename(columns={'fsid': 'fsid_placeholder'}, inplace=True)
@@ -270,7 +324,7 @@ def format_probability_count_summary(data):
         df.rename(columns={'fsid_placeholder': 'fsid'}, inplace=True)
         if 'subtype' not in df:
             df['subtype'] = pd.NA
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['location_fips'] = df['location_fips'].astype('Int64').apply(str)
         df['year'] = df['year'].astype('Int64').apply(str)
         df['low'] = df['low'].astype('Int64').apply(str)
@@ -278,14 +332,17 @@ def format_probability_count_summary(data):
         df['high'] = df['high'].astype('Int64').apply(str)
 
     else:
+        df.rename(columns={'fsid_placeholder': 'fsid'}, inplace=True)
         df['location_fips'] = pd.NA
         df['location_name'] = pd.NA
+        df['subtype'] = pd.NA
         df['year'] = pd.NA
         df['low'] = pd.NA
         df['mid'] = pd.NA
         df['high'] = pd.NA
 
-    return df[['fsid', 'location', 'location_fips', 'location_name', 'subtype', 'year', 'low', 'mid', 'high']]
+    return df[['fsid', 'valid_id', 'location', 'location_fips',
+               'location_name', 'subtype', 'year', 'low', 'mid', 'high']]
 
 
 def format_probability_cumulative(data):
@@ -302,12 +359,15 @@ def format_probability_cumulative(data):
         df = df.explode('data').reset_index(drop=True)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['year'] = df['year'].astype('Int64').apply(str)
         df['threshold'] = df['threshold'].astype('Int64').apply(str)
-        df['low'] = df['low'].round(3)
-        df['mid'] = df['mid'].round(3)
-        df['high'] = df['high'].round(3)
+        if df['low'] is None:
+            df['low'] = df['low'].round(3)
+        if df['mid'] is None:
+            df['mid'] = df['mid'].round(3)
+        if df['high'] is None:
+            df['high'] = df['high'].round(3)
     else:
         df['fsid'] = df['fsid'].apply(str)
         df.drop(['cumulative'], axis=1, inplace=True)
@@ -317,7 +377,7 @@ def format_probability_cumulative(data):
         df['mid'] = pd.NA
         df['high'] = pd.NA
 
-    return df[['fsid', 'year', 'threshold', 'low', 'mid', 'high']]
+    return df[['fsid', 'valid_id', 'year', 'threshold', 'low', 'mid', 'high']]
 
 
 def format_probability_depth(data):
@@ -334,14 +394,14 @@ def format_probability_depth(data):
         df = df.explode('data').reset_index(drop=True)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['year'] = df['year'].astype('Int64').apply(str)
         df['returnPeriod'] = df['returnPeriod'].astype('Int64').apply(str)
         df['low'] = df['low'].astype('Int64').apply(str)
         df['mid'] = df['mid'].astype('Int64').apply(str)
         df['high'] = df['high'].astype('Int64').apply(str)
     else:
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df.drop(['depth'], axis=1, inplace=True)
         df['year'] = pd.NA
         df['returnPeriod'] = pd.NA
@@ -349,7 +409,7 @@ def format_probability_depth(data):
         df['mid'] = pd.NA
         df['high'] = pd.NA
 
-    return df[['fsid', 'year', 'returnPeriod', 'low', 'mid', 'high']]
+    return df[['fsid', 'valid_id', 'year', 'returnPeriod', 'low', 'mid', 'high']]
 
 
 def format_environmental_precipitation(data):
@@ -364,7 +424,7 @@ def format_environmental_precipitation(data):
     if not df['projected'].isna().values.all():
         df = pd.concat([df.drop(['projected'], axis=1), df['projected'].apply(pd.Series)], axis=1)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['year'] = df['year'].astype('Int64').apply(str)
         df['low'] = df['low'].round(3)
         df['mid'] = df['mid'].round(3)
@@ -377,7 +437,7 @@ def format_environmental_precipitation(data):
         df['mid'] = pd.NA
         df['high'] = pd.NA
 
-    return df[['fsid', 'year', 'low', 'mid', 'high']]
+    return df[['fsid', 'valid_id', 'year', 'low', 'mid', 'high']]
 
 
 def format_historic_event(data):
@@ -389,7 +449,6 @@ def format_historic_event(data):
         A pandas formatted DataFrame
     """
     df = pd.DataFrame([vars(o) for o in data])
-    df.drop(["geometry"], axis=1, inplace=True)
     if not df['properties'].isna().values.all():
         df = pd.concat([df.drop(['properties'], axis=1), df['properties'].apply(pd.Series)], axis=1)
         df['eventId'] = df['eventId'].astype('Int64').apply(str)
@@ -404,8 +463,11 @@ def format_historic_event(data):
         df.drop(['properties'], axis=1, inplace=True)
         df['propertiesTotal'] = pd.NA
         df['propertiesAffected'] = pd.NA
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
 
-    return df[['eventId', 'name', 'month', 'year', 'returnPeriod', 'type', 'propertiesTotal', 'propertiesAffected']]
+    return df[['eventId', 'valid_id', 'name', 'month', 'year', 'returnPeriod', 'type', 'propertiesTotal',
+               'propertiesAffected', 'latitude', 'longitude']]
 
 
 def format_historic_summary_property(data):
@@ -419,18 +481,18 @@ def format_historic_summary_property(data):
     df = pd.DataFrame([vars(o) for o in data]).explode('historic').reset_index(drop=True)
     if not df['historic'].isna().values.all():
         df = pd.concat([df.drop(['historic'], axis=1), df['historic'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df['eventId'] = df['eventId'].astype('Int64').apply(str)
         df['depth'] = df['depth'].astype('Int64').apply(str)
     else:
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df.drop(['historic'], axis=1, inplace=True)
         df['eventId'] = pd.NA
         df['name'] = pd.NA
         df['type'] = pd.NA
         df['depth'] = pd.NA
 
-    return df[['fsid', 'eventId', 'name', 'type', 'depth']]
+    return df[['fsid', 'valid_id', 'eventId', 'name', 'type', 'depth']]
 
 
 def format_historic_summary(data):
@@ -444,14 +506,15 @@ def format_historic_summary(data):
     df = pd.DataFrame([vars(o) for o in data]).explode('historic').reset_index(drop=True)
     if not df['historic'].isna().values.all():
         df = pd.concat([df.drop(['historic'], axis=1), df['historic'].apply(pd.Series)], axis=1)
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df = df.explode('data').reset_index(drop=True)
         df = pd.concat([df.drop(['data'], axis=1), df['data'].apply(pd.Series)], axis=1)
         df['eventId'] = df['eventId'].astype('Int64').apply(str)
+        df['type'] = df['type'].apply(str)
         df['bin'] = df['bin'].astype('Int64').apply(str)
         df['count'] = df['count'].astype('Int64').apply(str)
     else:
-        df['fsid'] = df['fsid'].astype('Int64').apply(str)
+        df['fsid'] = df['fsid'].apply(str)
         df.drop(['historic'], axis=1, inplace=True)
         df['eventId'] = pd.NA
         df['name'] = pd.NA
@@ -459,7 +522,37 @@ def format_historic_summary(data):
         df['bin'] = pd.NA
         df['count'] = pd.NA
 
-    return df[['fsid', 'eventId', 'name', 'type', 'bin', 'count']]
+    return df[['fsid', 'valid_id', 'eventId', 'name', 'type', 'bin', 'count']]
+
+
+def format_historic_summary_event_property(data):
+    """Reformat the list of data to Historic Summary Event Property format
+
+    Args:
+        data (list): A list of FSF object
+    Returns:
+        A pandas formatted DataFrame
+    """
+
+    summary = format_historic_summary_property(data[0])
+    event = format_historic_event(data[1])
+
+    return pd.merge(summary, event, on=['eventId', 'valid_id'], how='left')
+
+
+def format_historic_summary_event(data):
+    """Reformat the list of data to Historic Summary Event format
+
+    Args:
+        data (list): A list of FSF object
+    Returns:
+        A pandas formatted DataFrame
+    """
+
+    summary = format_historic_summary(data[0])
+    event = format_historic_event(data[1])
+
+    return pd.merge(summary, event, on=['eventId', 'valid_id'], how='left')
 
 
 def format_location_detail_property(data):
@@ -531,9 +624,11 @@ def format_location_detail_property(data):
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
     df['footprintId'] = df['footprintId'].astype('Int64').apply(str)
     df['elevation'] = df['city_fips'].apply(str)
-    return df[['fsid', 'streetNumber', 'route', 'city_fips', 'city_name', 'zipCode', 'neighborhood_fips',
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'streetNumber', 'route', 'city_fips', 'city_name', 'zipCode', 'neighborhood_fips',
                'neighborhood_name', 'tract_fips', 'county_fips', 'county_name', 'cd_fips',
-               'cd_name', 'state_fips', 'state_name', 'footprintId', 'elevation', 'fema']]
+               'cd_name', 'state_fips', 'state_name', 'footprintId', 'elevation', 'fema', 'latitude', 'longitude']]
 
 
 def format_location_detail_neighborhood(data):
@@ -576,8 +671,10 @@ def format_location_detail_neighborhood(data):
     df['city_fips'] = df['city_fips'].astype('Int64').apply(str)
     df['county_fips'] = df['county_fips'].astype('Int64').apply(str)
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
-    return df[['fsid', 'name', 'city_fips', 'city_name', 'county_fips', 'county_name', 'subtype',
-               'state_fips', 'state_name']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'name', 'city_fips', 'city_name', 'county_fips', 'county_name', 'subtype',
+               'state_fips', 'state_name', 'latitude', 'longitude']]
 
 
 def format_location_detail_city(data):
@@ -630,8 +727,10 @@ def format_location_detail_city(data):
     df['county_fips'] = df['county_fips'].astype('Int64').apply(str)
     df['neighborhood_fips'] = df['neighborhood_fips'].astype('Int64').apply(str)
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
-    return df[['fsid', 'name', 'lsad', 'zipCode', 'neighborhood_fips', 'neighborhood_name',
-               'county_fips', 'county_name', 'state_fips', 'state_name']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'name', 'lsad', 'zipCode', 'neighborhood_fips', 'neighborhood_name',
+               'county_fips', 'county_name', 'state_fips', 'state_name', 'latitude', 'longitude']]
 
 
 def format_location_detail_zcta(data):
@@ -674,7 +773,10 @@ def format_location_detail_zcta(data):
     df['city_fips'] = df['city_fips'].astype('Int64').apply(str)
     df['county_fips'] = df['county_fips'].astype('Int64').apply(str)
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
-    return df[['fsid', 'name', 'city_fips', 'city_name', 'county_fips', 'county_name', 'state_fips', 'state_name']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'name', 'city_fips', 'city_name', 'county_fips', 'county_name', 'state_fips',
+               'state_name', 'latitude', 'longitude']]
 
 
 def format_location_detail_tract(data):
@@ -708,7 +810,10 @@ def format_location_detail_tract(data):
     df['fsid'] = df['fsid'].apply(str)
     df['county_fips'] = df['county_fips'].astype('Int64').apply(str)
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
-    return df[['fsid', 'fips', 'county_fips', 'county_name', 'state_fips', 'state_name']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'fips', 'county_fips', 'county_name', 'state_fips', 'state_name',
+               'latitude', 'longitude']]
 
 
 def format_location_detail_county(data):
@@ -761,8 +866,10 @@ def format_location_detail_county(data):
     df['zipCode'] = df['zipCode'].astype('Int64').apply(str)
     df['cd_fips'] = df['cd_fips'].astype('Int64').apply(str)
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
-    return df[['fsid', 'city_fips', 'city_name', 'zipCode', 'fips', 'isCoastal', 'cd_fips',
-               'cd_name', 'state_fips', 'state_name']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'city_fips', 'city_name', 'zipCode', 'fips', 'isCoastal', 'cd_fips',
+               'cd_name', 'state_fips', 'state_name', 'latitude', 'longitude']]
 
 
 def format_location_detail_cd(data):
@@ -796,7 +903,10 @@ def format_location_detail_cd(data):
     df['fsid'] = df['fsid'].apply(str)
     df['county_fips'] = df['county_fips'].astype('Int64').apply(str)
     df['state_fips'] = df['state_fips'].astype('Int64').apply(str).apply(lambda x: x.zfill(2))
-    return df[['fsid', 'district', 'county_fips', 'county_name', 'state_fips', 'state_name']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'district', 'county_fips', 'county_name', 'state_fips', 'state_name',
+               'latitude', 'longitude']]
 
 
 def format_location_detail_state(data):
@@ -809,7 +919,9 @@ def format_location_detail_state(data):
     """
     df = pd.DataFrame([vars(o) for o in data])
     df['fsid'] = df['fsid'].apply(str)
-    return df[['fsid', 'name', 'fips']]
+    df['geometry'] = df['geometry'].apply(get_geom_center)
+    df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
+    return df[['fsid', 'valid_id', 'name', 'fips', 'latitude', 'longitude']]
 
 
 def format_location_summary_property(data):
@@ -827,7 +939,7 @@ def format_location_summary_property(data):
     df['historic'] = df['historic'].astype('Int64').apply(str)
     df['adaptation'] = df['adaptation'].astype('Int64').apply(str)
     df['floodFactor'] = df['floodFactor'].astype('Int64').apply(str)
-    return df[['fsid', 'floodFactor', 'riskDirection', 'environmentalRisk', 'historic', 'adaptation']]
+    return df[['fsid', 'valid_id', 'floodFactor', 'riskDirection', 'environmentalRisk', 'historic', 'adaptation']]
 
 
 def format_location_summary(data):
@@ -855,7 +967,8 @@ def format_location_summary(data):
     df['adaptation'] = df['adaptation'].astype('Int64').apply(str)
     df['propertiesTotal'] = df['propertiesTotal'].astype('Int64').apply(str)
     df['propertiesAtRisk'] = df['propertiesAtRisk'].astype('Int64').apply(str)
-    return df[['fsid', 'riskDirection', 'environmentalRisk', 'propertiesTotal', 'propertiesAtRisk', 'historic']]
+    return df[['fsid', 'valid_id', 'riskDirection', 'environmentalRisk', 'propertiesTotal',
+               'propertiesAtRisk', 'historic']]
 
 
 def format_fema_nfip(data):
@@ -875,5 +988,5 @@ def format_fema_nfip(data):
     df['buildingCoverage'] = df['buildingCoverage'].astype('Int64').apply(str)
     df['contentCoverage'] = df['contentCoverage'].astype('Int64').apply(str)
     df['iccPaid'] = df['iccPaid'].astype('Int64').apply(str)
-    return df[['fsid', 'claimCount', 'policyCount', 'buildingPaid', 'contentPaid', 'buildingCoverage',
+    return df[['fsid', 'valid_id', 'claimCount', 'policyCount', 'buildingPaid', 'contentPaid', 'buildingCoverage',
                'contentCoverage', 'iccPaid']]
